pub enum HorizontalAlign {
Left,
Center,
Right,
LeftToRight,
RightToLeft,
}Expand description
Horizontal alignment policy for relative positioning.
Variants
Left
Center
Right
LeftToRight
Place directly adjacent to the right outer edge of reference.
RightToLeft
Place directly adjacent to the left outer edge of reference.