PartialBandBuffer

Struct PartialBandBuffer 

pub struct PartialBandBuffer<const N: usize> { /* private fields */ }
A fixed-capacity row-band buffer for partial rendering. Allows rendering large displays in narrow horizontal slices (e.g. 10-20 lines), requiring only a small fraction of the SRAM (e.g., 2–8 KB instead of 150 KB).

Implementations

Source

impl<const N: usize> PartialBandBuffer<N>

pub const fn new(width: usize, height: usize) -> Self

pub const fn width(&self) -> usize

pub const fn height(&self) -> usize

pub fn buffer(&self) -> &[Rgb565]

pub fn buffer_mut(&mut self) -> &mut [Rgb565]

pub fn clear_color(&mut self, color: Rgb565)

pub fn render_tasks_banded<D, const CAP: usize>( &mut self, _viewport: Rect, dirty_rect: Rect, tasks: &DrawTaskQueue<'_, CAP>, target: &mut D, clear_color: Option<Rgb565>, ) -> Result<(), D::Error>
where D: WindowedDrawTarget<Color = Rgb565>,

Renders draw tasks overlapping dirty_rect in horizontal slices of height self.height, flushing each rendered band directly to a WindowedDrawTarget.