TransitionPreset

Enum TransitionPreset 

pub enum TransitionPreset {
Show 23 variants None, WindowPush, WindowPop, WindowPushRound, WindowPopRound, ShutterUp, ShutterDown, ShutterLeft, ShutterRight, RoundFlipToLauncher, RoundFlipFromLauncher, PortHoleUp, PortHoleDown, PortHoleLeft, PortHoleRight, ModalPresent, ModalDismiss, TimelineSlide, TimelinePeekIn, TimelinePeekOut, TimelinePinExpand, TimelineScrubSettle, Fade,
}
Built-in screen transition presets for common navigation patterns.

Variants



None

Instant cut (no animation).



WindowPush

Horizontal push onto the stack (spatial moook curve).



WindowPop

Horizontal pop off the stack (spatial moook curve).



WindowPushRound

Round-style push (two-phase port-hole slide).



WindowPopRound

Round-style pop (two-phase port-hole slide).



ShutterUp

Directional shutter wipes.



ShutterDown



ShutterLeft



ShutterRight



RoundFlipToLauncher

Card-style flip toward launcher.



RoundFlipFromLauncher

Card-style flip from launcher.



PortHoleUp

Two-phase port-hole slides.



PortHoleDown



PortHoleLeft



PortHoleRight



ModalPresent

Modal presented from the bottom.



ModalDismiss

Modal dismissed toward the bottom.



TimelineSlide

Timeline-style horizontal slide.



TimelinePeekIn

Timeline peek card enters with a soft rightward reveal.



TimelinePeekOut

Timeline peek card exits with a soft leftward collapse.



TimelinePinExpand

Timeline pin details expand from lower edge.



TimelineScrubSettle

Timeline scrub release settles quickly.



Fade

Cross-fade.

Implementations