pub type Length = Constraint;Aliased Type
pub enum Length {
Min(u32),
Max(u32),
Length(u32),
Percent(u8),
Ratio(u32, u32),
Fill(u16),
}Variants
Min(u32)
Request at least this many pixels in the current single-pass solver.
Max(u32)
Request no more than this many pixels in the current single-pass solver.
Length(u32)
Request an exact number of pixels.
Percent(u8)
Request a percentage of the available main-axis space after gaps.
Ratio(u32, u32)
Request a ratio of the available main-axis space after gaps.
Fill(u16)
Share remaining main-axis space with other fill items by weight.